//
//  RedLaserSDK.h
//  ScanditBarcodeScanner
//
//  Created by Moritz Hartmeier on 20/08/15.
//  Copyright (c) 2015 Scandit AG. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <UIKit/UIKit.h>

#import "BarcodePickerController.h"
#import "BarcodeResult.h"


typedef enum
{
    RLState_EvalModeReady = 1,
    RLState_LicensedModeReady = 2,
    
    RLState_MissingOSLibraries = -1,
    RLState_NoCamera = -2,
    RLState_BadLicense = -3,
    RLState_ScanLimitReached = -4,
    RLState_NoKeychainAccess = -5,
    RLState_NoVideoAuthorization = -6,
} RedLaserStatus;


/*******************************************************************************
 RL_RequestVideoAuthorization
 
 This function returns immediately and fires a completion handler block with the state of the user permissions.
 This completion handler fires on an arbitrary queue that is not necessarily the main queue.
 The SDK will call your completion handler with RL_VideoAuthorizationStatusAuthorized to indicate that the user has granted permission to access the video camera.
 */

typedef NS_ENUM(NSInteger, RL_VideoAuthorizationStatus) {
    RL_VideoAuthorizationStatusNotDetermined = 0,
    RL_VideoAuthorizationStatusRestricted,
    RL_VideoAuthorizationStatusDenied,
    RL_VideoAuthorizationStatusAuthorized
};

typedef void (^RL_RequestVideoAuthorizationCompletionHandler)(RL_VideoAuthorizationStatus);

void RL_RequestVideoAuthorization(RL_RequestVideoAuthorizationCompletionHandler);

/*******************************************************************************
	FindBarcodesInUIImage
	
	Searches the given image for barcodes, and returns information on all barcodes
	that it finds. This performs an exhaustive search, which can take several
	seconds to perform. This method searches for all barcode types. The intent
	of this method is to allow for barcode searching in photos from the photo library.
 */
NSSet *FindBarcodesInUIImage(UIImage *inputImage);




/*******************************************************************************
	RL_GetRedLaserSDKVersion()
	
	This function returns the version of the RedLaser SDK, as a NSString.
	The primary purpose of this function is checking which SDK version you're
	linking against, to compare that version against the most recent version
	on redlaser.com.
 */
NSString *RL_GetRedLaserSDKVersion();

/*******************************************************************************
	RL_CheckReadyStatus()
	
	This function returns information about whether the SDK can be used. It
	doesn't give dynamic state information about what the SDK is currently doing.
	
	Generally, positive values mean you can scan, negative values mean you
	can't. The returned value *can* change from one call to the next.
	
	If this function returns a negative value, it's usually best to design your
	app so that it won't attempt to scan at all. If this function returns
	MissingOSLibraries this is especially important, as the SDK will probably
	crash if used. See the documentation.
 */
RedLaserStatus RL_CheckReadyStatus();


@interface RedLaserSDK : NSObject

@end
